Binary Operations
=================

.. https://docs.scipy.org/doc/numpy/reference/routines.bitwise.html

Elementwise bit operations
--------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.bitwise_and
   cupy.bitwise_or
   cupy.bitwise_xor
   cupy.invert
   cupy.left_shift
   cupy.right_shift


Bit packing
-----------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.packbits
   cupy.unpackbits


Output formatting
-----------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.binary_repr
